@@ -14,6 +14,8 @@
 #    under the License.
 from __future__ import absolute_import
 
+from oslo_log import log as logging
+
 from placement.conf import api
 from placement.conf import base
 from placement.conf import database
@@ -21,7 +23,7 @@ from placement.conf import paths
 from placement.conf import placement
 
 
-# To avoid global config, we require an existing ConfigOpts is passed
+# To avoid global config, we require an existing ConfigOpts to be passed
 # to register_opts. Then the caller can have some assurance that the
 # config they are using will maintain some independence.
 def register_opts(conf):
@@ -30,3 +32,4 @@ def register_opts(conf):
     database.register_opts(conf)
     paths.register_opts(conf)
     placement.register_opts(conf)
+    logging.register_options(conf)
