@@ -27,6 +27,7 @@ from placement import exception
 from placement.handlers import util as data_util
 from placement.i18n import _
 from placement import microversion
+from placement.objects import allocation as alloc_obj
 from placement.objects import resource_provider as rp_obj
 from placement.policies import allocation as policies
 from placement.schemas import allocation as schema
@@ -160,12 +161,12 @@ def _serialize_allocations_for_resource_provider(allocations,
 # _new_allocations it's being left here for now. We need a place for shared
 # handler code, but util.py is already too big and too diverse.
 def create_allocation_list(context, data, consumers):
-    """Create an AllocationList based on provided data.
+    """Create a list of Allocations based on provided data.
 
     :param context: The placement context.
     :param data: A dictionary of multiple allocations by consumer uuid.
     :param consumers: A dictionary, keyed by consumer UUID, of Consumer objects
-    :return: An AllocationList.
+    :return: A list of Allocation objects.
     :raises: `webob.exc.HTTPBadRequest` if a resource provider included in the
              allocations does not exist.
     """
@@ -188,13 +189,13 @@ def create_allocation_list(context, data, consumers):
             # The allocations are empty, which means wipe them out.
             # Internal to the allocation object this is signalled by a
             # used value of 0.
-            allocations = rp_obj.AllocationList.get_all_by_consumer_id(
+            allocations = alloc_obj.get_all_by_consumer_id(
                 context, consumer_uuid)
             for allocation in allocations:
                 allocation.used = 0
                 allocation_objects.append(allocation)
 
-    return rp_obj.AllocationList(context, objects=allocation_objects)
+    return allocation_objects
 
 
 def inspect_consumers(context, data, want_version):
@@ -250,8 +251,7 @@ def list_for_consumer(req):
     # NOTE(cdent): There is no way for a 404 to be returned here,
     # only an empty result. We do not have a way to validate a
     # consumer id.
-    allocations = rp_obj.AllocationList.get_all_by_consumer_id(
-        context, consumer_id)
+    allocations = alloc_obj.get_all_by_consumer_id(context, consumer_id)
 
     output = _serialize_allocations_for_consumer(allocations, want_version)
     last_modified = _last_modified_from_allocations(allocations, want_version)
@@ -290,7 +290,7 @@ def list_for_resource_provider(req):
             _("Resource provider '%(rp_uuid)s' not found: %(error)s") %
             {'rp_uuid': uuid, 'error': exc})
 
-    allocs = rp_obj.AllocationList.get_all_by_resource_provider(context, rp)
+    allocs = alloc_obj.get_all_by_resource_provider(context, rp)
 
     output = _serialize_allocations_for_resource_provider(
         allocs, rp, want_version)
@@ -321,10 +321,9 @@ def _resource_providers_by_uuid(ctx, rp_uuids):
         # TODO(jaypipes): Clearly, this is not efficient to do one query for
         # each resource provider UUID in the allocations instead of doing a
         # single query for all the UUIDs. However, since
-        # ResourceProviderList.get_all_by_filters() is way too complicated for
+        # rp_obj.get_all_by_filters() is way too complicated for
         # this purpose and doesn't raise NotFound anyway, we'll do this.
-        # Perhaps consider adding a ResourceProviderList.get_all_by_uuids()
-        # later on?
+        # Perhaps consider adding a rp_obj.get_all_by_uuids() later on?
         try:
             res[rp_uuid] = rp_obj.ResourceProvider.get_by_uuid(ctx, rp_uuid)
         except exception.NotFound:
@@ -347,7 +346,7 @@ def _new_allocations(context, resource_provider, consumer, resources):
     """
     allocations = []
     for resource_class in resources:
-        allocation = rp_obj.Allocation(
+        allocation = alloc_obj.Allocation(
             resource_provider=resource_provider,
             consumer=consumer,
             resource_class=resource_class,
@@ -409,11 +408,10 @@ def _set_allocations_for_consumer(req, schema):
         # NOTE(jaypipes): This will only occur 1.28+. The JSONSchema will
         # prevent an empty allocations object from being passed when there is
         # no consumer generation, so this is safe to do.
-        data_util.ensure_consumer(context, consumer_uuid,
-             data.get('project_id'), data.get('user_id'),
-             data.get('consumer_generation'), want_version)
-        allocations = rp_obj.AllocationList.get_all_by_consumer_id(
-            context, consumer_uuid)
+        data_util.ensure_consumer(
+            context, consumer_uuid, data.get('project_id'),
+            data.get('user_id'), data.get('consumer_generation'), want_version)
+        allocations = alloc_obj.get_all_by_consumer_id(context, consumer_uuid)
         for allocation in allocations:
             allocation.used = 0
             allocation_objects.append(allocation)
@@ -433,28 +431,24 @@ def _set_allocations_for_consumer(req, schema):
                                                allocation['resources'])
             allocation_objects.extend(new_allocations)
 
-    allocations = rp_obj.AllocationList(
-        context, objects=allocation_objects)
-
     def _create_allocations(alloc_list):
         try:
-            alloc_list.replace_all()
+            alloc_obj.replace_all(context, alloc_list)
             LOG.debug("Successfully wrote allocations %s", alloc_list)
         except Exception:
-            if created_new_consumer:
-                delete_consumers([consumer])
-            raise
+            with excutils.save_and_reraise_exception():
+                if created_new_consumer:
+                    delete_consumers([consumer])
 
     try:
-        _create_allocations(allocations)
+        _create_allocations(allocation_objects)
     # InvalidInventory is a parent for several exceptions that
     # indicate either that Inventory is not present, or that
     # capacity limits have been exceeded.
     except exception.NotFound as exc:
         raise webob.exc.HTTPBadRequest(
-                _("Unable to allocate inventory for consumer "
-                  "%(consumer_uuid)s: %(error)s") %
-            {'consumer_uuid': consumer_uuid, 'error': exc})
+            _("Unable to allocate inventory for consumer %(consumer_uuid)s: "
+              "%(error)s") % {'consumer_uuid': consumer_uuid, 'error': exc})
     except exception.InvalidInventory as exc:
         raise webob.exc.HTTPConflict(
             _('Unable to allocate inventory: %(error)s') % {'error': exc})
@@ -462,7 +456,7 @@ def _set_allocations_for_consumer(req, schema):
         raise webob.exc.HTTPConflict(
             _('Inventory and/or allocations changed while attempting to '
               'allocate: %(error)s') % {'error': exc},
-              comment=errors.CONCURRENT_UPDATE)
+            comment=errors.CONCURRENT_UPDATE)
 
     req.response.status = 204
     req.response.content_type = None
@@ -512,18 +506,18 @@ def set_allocations(req):
     consumers, new_consumers_created = inspect_consumers(
         context, data, want_version)
     # Create a sequence of allocation objects to be used in one
-    # AllocationList.replace_all() call, which will mean all the changes
+    # alloc_obj.replace_all() call, which will mean all the changes
     # happen within a single transaction and with resource provider
     # and consumer generations (if applicable) check all in one go.
     allocations = create_allocation_list(context, data, consumers)
 
     def _create_allocations(alloc_list):
         try:
-            alloc_list.replace_all()
+            alloc_obj.replace_all(context, alloc_list)
             LOG.debug("Successfully wrote allocations %s", alloc_list)
         except Exception:
-            delete_consumers(new_consumers_created)
-            raise
+            with excutils.save_and_reraise_exception():
+                delete_consumers(new_consumers_created)
 
     try:
         _create_allocations(allocations)
@@ -540,7 +534,7 @@ def set_allocations(req):
         raise webob.exc.HTTPConflict(
             _('Inventory and/or allocations changed while attempting to '
               'allocate: %(error)s') % {'error': exc},
-              comment=errors.CONCURRENT_UPDATE)
+            comment=errors.CONCURRENT_UPDATE)
 
     req.response.status = 204
     req.response.content_type = None
@@ -553,19 +547,18 @@ def delete_allocations(req):
     context.can(policies.ALLOC_DELETE)
     consumer_uuid = util.wsgi_path_item(req.environ, 'consumer_uuid')
 
-    allocations = rp_obj.AllocationList.get_all_by_consumer_id(
-        context, consumer_uuid)
+    allocations = alloc_obj.get_all_by_consumer_id(context, consumer_uuid)
     if allocations:
         try:
-            allocations.delete_all()
+            alloc_obj.delete_all(context, allocations)
         # NOTE(pumaranikar): Following NotFound exception added in the case
         # when allocation is deleted from allocations list by some other
         # activity. In that case, delete_all() will throw a NotFound exception.
         except exception.NotFound as exc:
             raise webob.exc.HTTPNotFound(
-                  _("Allocation for consumer with id %(id)s not found."
-                    "error: %(error)s") %
-                  {'id': consumer_uuid, 'error': exc})
+                _("Allocation for consumer with id %(id)s not found. error: "
+                  "%(error)s") %
+                {'id': consumer_uuid, 'error': exc})
     else:
         raise webob.exc.HTTPNotFound(
             _("No allocations for consumer '%(consumer_uuid)s'") %
